@@ -120,8 +120,8 @@ class EVA:
         self.__model: typing.Optional[typing.Union[MLE, Emcee]] = None
 
         logger.info(
-            f"successfully initialized EVA object "
-            f"with data of length {len(self.data):,d}"
+            "successfully initialized EVA object with data of length %d"
+            % len(self.data)
         )
 
     @property
@@ -207,9 +207,9 @@ class EVA:
         def align_text(label: str, value: str, position: str) -> str:
             if label == "":
                 if position == "left":
-                    return f"{value:>{lwidth:d}}"
+                    return f"{value:>{lwidth}}"
                 elif position == "right":
-                    return f"{value:>{rwidth:d}}"
+                    return f"{value:>{rwidth}}"
                 else:
                     raise AssertionError
 
@@ -234,13 +234,13 @@ class EVA:
             aligned_text = []
             for i, chunk in enumerate(value_chunks):
                 if i == 0:
-                    aligned_text.append(f"{label}: {chunk:>{free_width:d}}")
+                    aligned_text.append(f"{label}: {chunk:>{free_width}}")
                 else:
                     aligned_text.append(
                         "".join(
                             [
                                 " " * label_width,
-                                f"{chunk:>{free_width:d}}",
+                                f"{chunk:>{free_width}}",
                             ]
                         )
                     )
@@ -431,7 +431,7 @@ class EVA:
         kwargs
             if method is BM:
                 block_size : str or pandas.Timedelta, optional
-                    Block size (default='1Y').
+                    Block size (default='365.2425D').
                 errors : str, optional
                     raise (default) - raise an exception
                         when encountering a block with no data
@@ -439,6 +439,11 @@ class EVA:
                     coerce - get extreme values for blocks with no data
                         as mean of all other extreme events in the series
                         with index being the middle point of corresponding interval
+                    min_last_block : float, optional
+                        Minimum data availability ratio (0 to 1) in the last block
+                        for it to be used to extract extreme value from.
+                        This is used to discard last block when it is too short.
+                        If None (default), last block is always used.
             if method is POT:
                 threshold : float
                     Threshold used to find exceedances.
@@ -448,26 +453,33 @@ class EVA:
 
         """
         message = f"for method='{method}' and extremes_type='{extremes_type}'"
-        logger.debug(f"extracting extreme values {message}")
+        logger.debug("extracting extreme values %s" % message)
         self.__extremes = get_extremes(
             method=method, ts=self.data, extremes_type=extremes_type, **kwargs
         )
         self.__extremes_method = method
         self.__extremes_type = extremes_type
-        logger.info(f"successfully extracted extreme values {message}")
+        logger.info("successfully extracted extreme values %s" % message)
 
-        logger.debug("collecting extreme value properties ")
+        logger.debug("collecting extreme value properties")
         self.__extremes_kwargs = {}
         if method == "BM":
             self.__extremes_kwargs["block_size"] = pd.to_timedelta(
-                kwargs.get("block_size", "1Y")
+                kwargs.pop("block_size", "365.2425D")
+            )
+            self.__extremes_kwargs["errors"] = kwargs.pop("errors", "raise")
+            self.__extremes_kwargs["min_last_block"] = kwargs.pop(
+                "min_last_block", None
             )
-            self.__extremes_kwargs["errors"] = kwargs.get("errors", "raise")
         elif method == "POT":
-            self.__extremes_kwargs["threshold"] = kwargs["threshold"]
-            self.__extremes_kwargs["r"] = pd.to_timedelta(kwargs.get("r", "24H"))
+            self.__extremes_kwargs["threshold"] = kwargs.pop("threshold")
+            self.__extremes_kwargs["r"] = pd.to_timedelta(kwargs.pop("r", "24H"))
         else:
             raise AssertionError
+        if len(kwargs) != 0:
+            raise TypeError(
+                f"unrecognized arguments passed in: {', '.join(kwargs.keys())}"
+            )
         logger.info("successfully collected extreme value properties")
 
         logger.debug("creating extremes transformer")
@@ -577,8 +589,8 @@ class EVA:
         # Select default distribution
         if distribution is None:
             logger.debug(
-                f"selecting default distribution for extremes extracted using the "
-                f"'{self.extremes_method}' method"
+                "selecting default distribution for extremes extracted using the "
+                "'%s' method" % self.extremes_method
             )
 
             # Prepare list of candidate distributions
@@ -598,18 +610,19 @@ class EVA:
 
             # Fit MLE model for candidate distributions
             # and select distribution with smallest AIC
-            candidate_models = {
-                distribution_name: MLE(
+            distribution = None
+            aic = np.inf
+            for distribution_name in candidate_distributions:
+                new_aic = MLE(
                     extremes=self.extremes_transformer.transformed_extremes,
                     distribution=distribution_name,
                     distribution_kwargs=_distribution_kwargs,
                 ).AIC
-                for distribution_name in candidate_distributions
-            }
-            distribution = min(candidate_models, key=candidate_models.get)
+                if new_aic < aic:
+                    distribution = distribution_name
+                    aic = new_aic
             logger.info(
-                f"selected '{distribution}' distribution "
-                f"with AIC score {candidate_models[distribution]}"
+                "selected '%s' distribution with AIC score %s" % (distribution, aic)
             )
 
         # Get distribution name
@@ -671,8 +684,8 @@ class EVA:
                 )
             }
             logger.debug(
-                f"freezing location parameter (floc) at {distribution_kwargs['floc']} "
-                f"for '{distribution_name}' distribution"
+                "freezing location parameter (floc) at %s for '%s' distribution"
+                % (distribution_kwargs["floc"], distribution_name)
             )
 
         # Fit model to transformed extremes
@@ -798,7 +811,7 @@ class EVA:
     def get_return_value(
         self,
         return_period,
-        return_period_size: typing.Union[str, pd.Timedelta] = "1Y",
+        return_period_size: typing.Union[str, pd.Timedelta] = "365.2425D",
         alpha: typing.Optional[float] = None,
         **kwargs,
     ) -> tuple:
@@ -811,7 +824,7 @@ class EVA:
             Return period or 1D array of return periods.
             Given as a multiple of `return_period_size`.
         return_period_size : str or pandas.Timedelta, optional
-            Size of return periods (default='1Y').
+            Size of return periods (default='365.2425D').
             If set to '30D', then a return period of 12
             would be roughly equivalent to a 1 year return period (360 days).
         alpha : float, optional
@@ -884,7 +897,7 @@ class EVA:
     def get_summary(
         self,
         return_period,
-        return_period_size: typing.Union[str, pd.Timedelta] = "1Y",
+        return_period_size: typing.Union[str, pd.Timedelta] = "365.2425D",
         alpha: typing.Optional[float] = None,
         **kwargs,
     ) -> pd.DataFrame:
@@ -897,7 +910,7 @@ class EVA:
             Return period or 1D array of return periods.
             Given as a multiple of `return_period_size`.
         return_period_size : str or pandas.Timedelta, optional
-            Size of return periods (default='1Y').
+            Size of return periods (default='365.2425D').
             If set to '30D', then a return period of 12
             would be roughly equivalent to a 1 year return period (360 days).
         alpha : float, optional
@@ -955,7 +968,7 @@ class EVA:
     def plot_return_values(
         self,
         return_period=None,
-        return_period_size: typing.Union[str, pd.Timedelta] = "1Y",
+        return_period_size: typing.Union[str, pd.Timedelta] = "365.2425D",
         alpha: typing.Optional[float] = None,
         plotting_position: str = "weibull",
         ax: typing.Optional[plt.Axes] = None,
@@ -973,7 +986,7 @@ class EVA:
             If None (default), calculates as 100 values uniformly spaced
             within the range of return periods of the extracted extreme values.
         return_period_size : str or pandas.Timedelta, optional
-            Size of return periods (default='1Y').
+            Size of return periods (default='365.2425D').
             If set to '30D', then a return period of 12
             would be roughly equivalent to a 1 year return period (360 days).
         alpha : float, optional
@@ -1062,7 +1075,7 @@ class EVA:
     def plot_probability(
         self,
         plot_type: str,
-        return_period_size: typing.Union[str, pd.Timedelta] = "1Y",
+        return_period_size: typing.Union[str, pd.Timedelta] = "365.2425D",
         plotting_position: str = "weibull",
         ax: typing.Optional[plt.Axes] = None,
         figsize: tuple = (8, 8),
@@ -1078,7 +1091,7 @@ class EVA:
                 PP - probability plot
                 QQ - quantile plot
         return_period_size : str or pandas.Timedelta, optional
-            Size of return periods (default='1Y').
+            Size of return periods (default='365.2425D').
             If set to '30D', then a return period of 12
             would be roughly equivalent to a 1 year return period (360 days).
         plotting_position : str, optional
@@ -1146,7 +1159,7 @@ class EVA:
     def plot_diagnostic(
         self,
         return_period=None,
-        return_period_size: typing.Union[str, pd.Timedelta] = "1Y",
+        return_period_size: typing.Union[str, pd.Timedelta] = "365.2425D",
         alpha: typing.Optional[float] = None,
         plotting_position: str = "weibull",
         figsize: tuple = (8, 8),
@@ -1169,7 +1182,7 @@ class EVA:
             If None (default), calculates as 100 values uniformly spaced
             within the range of return periods of the extracted extreme values.
         return_period_size : str or pandas.Timedelta, optional
-            Size of return periods (default='1Y').
+            Size of return periods (default='365.2425D').
             If set to '30D', then a return period of 12
             would be roughly equivalent to a 1 year return period (360 days).
         alpha : float, optional
